==> vtk-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkReflectionFilter.java <==
// java wrapper for vtkReflectionFilter object
//

package vtk;
import vtk.*;

public class vtkReflectionFilter extends vtkDataObjectAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetPlane_2(int id0);
  public void SetPlane(int id0)
    { SetPlane_2(id0); }

  private native int GetPlaneMinValue_3();
  public int GetPlaneMinValue()
    { return GetPlaneMinValue_3(); }

  private native int GetPlaneMaxValue_4();
  public int GetPlaneMaxValue()
    { return GetPlaneMaxValue_4(); }

  private native int GetPlane_5();
  public int GetPlane()
    { return GetPlane_5(); }

  private native void SetPlaneToX_6();
  public void SetPlaneToX()
    { SetPlaneToX_6(); }

  private native void SetPlaneToY_7();
  public void SetPlaneToY()
    { SetPlaneToY_7(); }

  private native void SetPlaneToZ_8();
  public void SetPlaneToZ()
    { SetPlaneToZ_8(); }

  private native void SetPlaneToXMin_9();
  public void SetPlaneToXMin()
    { SetPlaneToXMin_9(); }

  private native void SetPlaneToYMin_10();
  public void SetPlaneToYMin()
    { SetPlaneToYMin_10(); }

  private native void SetPlaneToZMin_11();
  public void SetPlaneToZMin()
    { SetPlaneToZMin_11(); }

  private native void SetPlaneToXMax_12();
  public void SetPlaneToXMax()
    { SetPlaneToXMax_12(); }

  private native void SetPlaneToYMax_13();
  public void SetPlaneToYMax()
    { SetPlaneToYMax_13(); }

  private native void SetPlaneToZMax_14();
  public void SetPlaneToZMax()
    { SetPlaneToZMax_14(); }

  private native void SetCenter_15(double id0);
  public void SetCenter(double id0)
    { SetCenter_15(id0); }

  private native double GetCenter_16();
  public double GetCenter()
    { return GetCenter_16(); }

  private native void SetCopyInput_17(int id0);
  public void SetCopyInput(int id0)
    { SetCopyInput_17(id0); }

  private native int GetCopyInput_18();
  public int GetCopyInput()
    { return GetCopyInput_18(); }

  private native void CopyInputOn_19();
  public void CopyInputOn()
    { CopyInputOn_19(); }

  private native void CopyInputOff_20();
  public void CopyInputOff()
    { CopyInputOff_20(); }

  public vtkReflectionFilter() { super(); }

  public vtkReflectionFilter(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-3-aarch64.pkg.tar.xz: vtk/vtkReflectionFilter.java <==
// java wrapper for vtkReflectionFilter object
//

package vtk;
import vtk.*;

public class vtkReflectionFilter extends vtkDataObjectAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetPlane_2(int id0);
  public void SetPlane(int id0)
    { SetPlane_2(id0); }

  private native int GetPlaneMinValue_3();
  public int GetPlaneMinValue()
    { return GetPlaneMinValue_3(); }

  private native int GetPlaneMaxValue_4();
  public int GetPlaneMaxValue()
    { return GetPlaneMaxValue_4(); }

  private native int GetPlane_5();
  public int GetPlane()
    { return GetPlane_5(); }

  private native void SetPlaneToX_6();
  public void SetPlaneToX()
    { SetPlaneToX_6(); }

  private native void SetPlaneToY_7();
  public void SetPlaneToY()
    { SetPlaneToY_7(); }

  private native void SetPlaneToZ_8();
  public void SetPlaneToZ()
    { SetPlaneToZ_8(); }

  private native void SetPlaneToXMin_9();
  public void SetPlaneToXMin()
    { SetPlaneToXMin_9(); }

  private native void SetPlaneToYMin_10();
  public void SetPlaneToYMin()
    { SetPlaneToYMin_10(); }

  private native void SetPlaneToZMin_11();
  public void SetPlaneToZMin()
    { SetPlaneToZMin_11(); }

  private native void SetPlaneToXMax_12();
  public void SetPlaneToXMax()
    { SetPlaneToXMax_12(); }

  private native void SetPlaneToYMax_13();
  public void SetPlaneToYMax()
    { SetPlaneToYMax_13(); }

  private native void SetPlaneToZMax_14();
  public void SetPlaneToZMax()
    { SetPlaneToZMax_14(); }

  private native void SetCenter_15(double id0);
  public void SetCenter(double id0)
    { SetCenter_15(id0); }

  private native double GetCenter_16();
  public double GetCenter()
    { return GetCenter_16(); }

  private native void SetCopyInput_17(int id0);
  public void SetCopyInput(int id0)
    { SetCopyInput_17(id0); }

  private native int GetCopyInput_18();
  public int GetCopyInput()
    { return GetCopyInput_18(); }

  private native void CopyInputOn_19();
  public void CopyInputOn()
    { CopyInputOn_19(); }

  private native void CopyInputOff_20();
  public void CopyInputOff()
    { CopyInputOff_20(); }

  public vtkReflectionFilter() { super(); }

  public vtkReflectionFilter(long id) { super(id); }
  public native long   VTKInit();

}
